@@ -1,4 +1,5 @@
 import argparse
+from collections import defaultdict
 import os
 import re
 import sys
@@ -67,6 +68,9 @@ def parse(s):
                 is_uri(line) or is_vcs_uri(line):
             if line.startswith('-e'):
                 tmpstr = line[len('-e'):].strip()
+                # too short requirement format
+                if len(tmpstr) < 5:
+                    continue
             elif line.startswith('--editable'):
                 tmpstr = line[len('--editable'):].strip()
             else:
@@ -96,25 +100,36 @@ def _out(text, color):
 
 
 def lets_pipin():
+    cnt = defaultdict(int)
+    cnt_projects = 0
     filename = args.file or 'requirements.txt'
+
     for path, fpath in _locate(root=args.path, filename=filename):
+        cnt_projects += 1
         with open(fpath, 'r') as fopen:
-            items = parse(fopen)
-            items = ' '.join(items)
+            items = ' '.join(parse(fopen))
             _out(fpath.split('/')[-2].upper() + ' (' + fpath + ')', YELLOW)
 
             reapp = None
             for app in args.app:
                 if '*' in app:
-                    reapp = re.search('%s(.+)%s' % tuple(app.split('*')), items)
+                    reapp = re.search(r'\b%s\b([\>\=\<]+)%s' % tuple(app.split('*')), items)
                     reapp = reapp.group() if reapp else None
 
                 if reapp:
                     _out("%s found" % reapp, CYAN)
+                    cnt['%s_found' % app] += 1
                 elif app in items:
                     _out("%s found" % app, CYAN)
+                    cnt['%s_found' % app] += 1
                 else:
                     _out("%s not found" % app, RED)
+                    cnt['%s_not_found' % app] += 1
+
+    for app in args.app:
+        _out("\nSearched %s projects for %s:" % (cnt_projects, app), WHITE)
+        _out(" %s found" % cnt['%s_found' % app], CYAN)
+        _out(" %s not found" % cnt['%s_not_found' % app], RED)
 
 if __name__ == '__main__':
     lets_pipin()
